#
# spec file for package ghc-rpm-macros
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global without_hscolour 1
Name:           ghc-rpm-macros
Version:        1.9.95
Release:        150500.1.1
Summary:        RPM Macros for building packages for GHC
License:        GPL-3.0-or-later
Group:          Development/Libraries/Other
URL:            https://fedoraproject.org/wiki/Haskell_SIG
# source gets updated with osc service dr
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  xz
Requires:       rpm
BuildArch:      noarch
%if %{undefined without_hscolour}
Requires:       hscolour
%endif

%description
A set of macros for building GHC packages following the openSUSE
Haskell Guidelines.  ghc needs to be installed in
order to make use of these macros.

%package extra
Summary:        Extra RPM macros for building Haskell packages with several libs
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}

%description extra
Extra macros used for subpackaging of Haskell libraries,
for example in ghc and haskell-platform.

%package -n ghc-srpm-macros
Summary:        RPM macros for building Haskell source packages
Group:          Development/Libraries/Other
BuildArch:      noarch

%description -n ghc-srpm-macros
Macros used when generating source Haskell rpm packages.

%prep
%setup -q

%build
echo no build stage needed

%install
install -p -D -m 0644 macros.ghc %{buildroot}%{_rpmmacrodir}/macros.ghc
install -p -D -m 0644 macros.ghc-extra %{buildroot}/%{_rpmmacrodir}/macros.ghc-extra
install -p -D -m 0644 macros.ghc-suse %{buildroot}/%{_rpmmacrodir}/macros.ghc-suse
install -p -D -m 0755 ghc-deps.sh %{buildroot}/%{_prefix}/lib/rpm/ghc-deps.sh
install -p -D -m 0755 cabal-tweak-dep-ver %{buildroot}/%{_bindir}/cabal-tweak-dep-ver
install -p -D -m 0755 cabal-tweak-drop-dep %{buildroot}/%{_bindir}/cabal-tweak-drop-dep
install -p -D -m 0755 cabal-tweak-flag %{buildroot}/%{_bindir}/cabal-tweak-flag
install -p -D -m 0755 ghc-pkg-wrapper %{buildroot}/%{_prefix}/lib/rpm/ghc-pkg-wrapper
install -p -D -m 0644 ghc.attr %{buildroot}/%{_prefix}/lib/rpm/fileattrs/ghc.attr
install -p -D -m 0755 ghc-dirs.sh %{buildroot}/%{_prefix}/lib/rpm/ghc-dirs.sh
install -p -D -m 0644 Setup.hs %{buildroot}/%{_datadir}/%{name}/Setup.hs

%files
%doc AUTHORS
%license COPYING
%{_rpmmacrodir}/macros.ghc
%{_rpmmacrodir}/macros.ghc-suse
%{_prefix}/lib/rpm/ghc-deps.sh
%{_bindir}/cabal-tweak-dep-ver
%{_bindir}/cabal-tweak-flag
%{_bindir}/cabal-tweak-drop-dep
%{_prefix}/lib/rpm/ghc-pkg-wrapper
%{_prefix}/lib/rpm/fileattrs/ghc.attr
%{_prefix}/lib/rpm/ghc-dirs.sh
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/Setup.hs

%files extra
%{_rpmmacrodir}/macros.ghc-extra

%changelog
* Mon Nov  1 2021 mimi.vx@gmail.com
- fix build, remove white space
* Mon May 10 2021 mimi.vx@gmail.com
- move macros from etc - boo#1185672
* Thu May  7 2020 psimons@suse.com
- Update to version 1.9.95.
* Mon Dec 30 2019 mimi.vx@gmail.com
- add workaround for license
  needed for work on ppc64 ghc compiler
* Fri Dec 20 2019 mimi.vx@gmail.com
- update to 1.9.90
  * backport upstream changes
  * workaround for packages without Setup.hs file
  - drop no-selfbootstrap-check.patch
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Sun May 27 2018 ptrommler@icloud.com
- own license directory on older openSUSE
* Fri May  4 2018 ptrommler@icloud.com
- add no-selfbootstrap-check.patch
  * GHC's ABI is stable now so a selfbootstrapped compiler is
  no longer needed
* Wed Apr 18 2018 mimi.vx@gmail.com
- use %%license macro
- simplify dependecy generator
* Tue Mar 20 2018 mimi.vx@gmail.com
- update to 1.7.4
- sync with ustream
- support sublibraries
* Fri Jul 14 2017 mimi.vx@gmail.com
- update to 1.7.2
- disabled smp build -- it brokes reproduciblity of haskell packages
  * reported by bwiedemann@suse.com
* Mon May 29 2017 mimi.vx@gmail.com
- update to 1.7.1
- sync with upstream
* Fri Jan 20 2017 mimi.vx@gmail.com
- update to 1.6.95
- sync with upstream
  * fix compatibility with cabal 1.24.1.0 and 1.24.2.0
* Fri Oct 14 2016 mimi.vx@gmail.com
- sync with upstream
- ghc-pkg-wrapper is now quiet with simple output
- new ghc_fix_rpath macro deprecates ghc_fix_dynamic_rpath
- ghc_lib_subpackage now takes name-version
- new ghc_libs_build and ghc_libs_install extra macros
* Sat Jul 16 2016 mimi.vx@gmail.com
- update to 1.6.91
  * support multiple jobs during build and configure phase
* Tue Jun 28 2016 mimi.vx@gmail.com
- new macros.ghc-suse
- binary packages build statically linked
* Wed Jun 22 2016 mimi.vx@gmail.com
- update to 1.6.90
  * %%ghc_gen_filelists: uniq keyname to prevent build failure for installed version
* Sat May 28 2016 peter.trommler@ohm-hochschule.de
- doc dir contains ghc version, now incompactible with ghc 7.10
* Sun May 22 2016 mimi.vx@gmail.com
- Increase verbosity of configure and build macros
* Thu Mar 17 2016 mimi.vx@gmail.com
- update to 1.5.3
  * ghc_gen_filelists: determine keyname with pkgnamever not just pkgname
  * ghc-deps.sh no longer filter out ghc-prim and integer-gmp
* Thu Feb 18 2016 mimi.vx@gmail.com
- update to 1.5.0
- update for ghc-8.0
- ghc-deps uses --provides and --requires again
* Mon Oct 26 2015 mimi.vx@gmail.com
- update to 1.4.98
- dropped: fix-library-dir.patch
    suse-disable-debug-packages.patch
    suse-docdir.patch
    remove-flags.patch
    fix-gen-filelists.patch
  * fix some missing quoting for deps generation
  * add and use ghc-pkg-wrapper script
  * use ghc-pkg key field
* Wed Sep 16 2015 mimi.vx@gmail.com
- update to 1.4.94
- refreshed remove-flags.patch
- dropped add-group.patch and files-defattr.patch
* Thu Aug 27 2015 mimi.vx@gmail.com
- update to 1.4.93
- refreshed:
    add-group.patch
    files-defattr.patch
    fix-gen-filelists.patch
    fix-library-dir.patch
    suse-disable-debug-packages.patch
    suse-docdir.patch
- dropped:
    version-docdirs.patch
    fix-runpath.patch
    ldflags.patch
- added:
    remove-flags.patch
- fix ghc-pkg path in ghc-deps.sh for ghc-7.10
- local pkgdir macro is redundant
- use utf8 locale for cabal
- add explicit --enable-shared again for arm64
- introduce ghc_pkgdocdir since no _pkgdocdir in RHEL 7 and earlier
- allow overriding ghc- prefix with ghc_name (for ghc784 etc)
- version ghc-pkg in ghc_pkg_recache
- have to turn off hardening in cabal_configure: set _hardened_ldflags to nil
- add cabal_test macro
- only run cabal haddock for real libraries with modules
- make sure basepkg.files is also created for meta packages
- fix the R*PATH regexp
- version ghcpkgdocdir
- add new names ghc_html_dir, ghc_html_libraries_dir, and ghc_html_pkg_dir
- correct cabal-tweak-flag error message for missing flag
- update ghc_gen_filelists to use new keyed library filepaths
  and specify libHS*.so more loosely
- ghc-dep.sh now just makes versioned devel reqs
- rename ghc_lib.attr to ghc.attr and drop ghc_bin.attr
* Wed Aug 19 2015 mimi.vx@gmail.com
- update to fake version 1.4.8 based on 1.3.91
- dropped: sle-sp1-rpmdeps.patch
    fix-gen-filelists.patch
    remove-flags.patch
- added patches: ldflags.patch
    version-docdirs.patch
    fix-runpath.patch
    fix-library-dir.patch
* Tue Apr 14 2015 mimi.vx@gmail.com
- regenerated sle-sp1-rpmdeps.patch
* Fri Mar 27 2015 peter.trommler@ohm-hochschule.de
- add rpm library directory to files on older openSUSE
  * fix build on openSUSE 11.4
* Mon Feb 23 2015 peter.trommler@ohm-hochschule.de
- update to 1.4.7
- drop fix-runpath.patch
  * fixed upstream
- refresh fix-gen-filelists.patch
- refresh suse-disable-debug-packages.patch
- refresh suse-docdir.patch
- add remove-flags.patch
  * remove passing of CFLAGS and LDFLAGS to ghc
  * no macro %%__global_ldflags in openSUSE
- remove provides ghc() workaround
  * fixed upstream
* Sun Dec 14 2014 peter.trommler@ohm-hochschule.de
- make package noarch and remove rpmlintrc
* Sat Dec 13 2014 peter.trommler@ohm-hochschule.de
- do not disable dynamic libraries on ppc anymore
  * fixed by patch 18 in ghc.spec
* Tue Oct 21 2014 peter.trommler@ohm-hochschule.de
- update to 1.3.6
  * remove execstack workaround and prelink requirement
  * improve ghc_fix_dynamic_rpath macro
  * do not use -O2 optimization (out of memory failures on OBS)
- refresh patches:
  * add-group.patch
  * files-defattr.patch
  * fix-gen-filelists.patch
  * suse-disable-debug-packages.patch
  * suse-docdir.patch
-drop patch disable-execstack.patch
  * fixed in ghc 7.8
- add fix-runpath.patch
  * starting with ghc 7.8 shared objects with RUNPATH work
  * support RUNPATH as well as RPATH
- enable shared libraries and dynamic linking on ppc64 and ppc64le
  * shared libraries for ppc still disabled (see haskell trac #8024)
* Fri Sep 12 2014 dmueller@suse.com
- disable dependency on prelink for arm and aarch64 architectures
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Thu Jun 26 2014 peter.trommler@ohm-hochschule.de
- add rpmlintrc to spec file
* Thu Jun 26 2014 martin.koegler@chello.at
- SLES11 does not support a different BuildArch for subpackages
* Thu May 29 2014 peter.trommler@ohm-hochschule.de
- BR xz for SLE 11 builds
* Sat May 10 2014 peter.trommler@ohm-hochschule.de
- update to 1.2.7
  * set datasubdir in cabal_configure for ghc-7.8
  * abort ghc_fix_dynamic_rpath if no chrpath
  * update license tag to GPLv3+
  * set Url field when generating subpackages
- refresh patches add-group.patch, files-defattr.patch,
  fix-genfilelists.patch, suse-disable-debug-patches.patch
- remove macros.ghc-suse
  * they never worked on OBS
- add patch disable-execstack.patch
  * disable execstack workaround on ppc64le
  * prelink is not available on ppc64le yet
  * ghc does not handle executable stack note properly
    you will probably get rpmlint warnings about it
* Sat Feb  1 2014 peter.trommler@ohm-hochschule.de
- update to 1.2.2
  * fix error message
- use stable URL (no git hash)
* Mon Dec 16 2013 peter.trommler@ohm-hochschule.de
- add requires prelink
  * need execstack to fix ghc generated binaries
* Fri Dec 13 2013 peter.trommler@ohm-hochschule.de
- fix suse-docdir.patch
  * define _pkgdocdir macro
* Wed Dec 11 2013 peter.trommler@ohm-hochschule.de
- refresh sle-sp1-rpmdeps.patch
* Tue Oct 29 2013 peter.trommler@ohm-hochschule.de
- disable colorized documentation for ppc bootstrap
* Sat Oct 26 2013 peter.trommler@ohm-hochschule.de
- fix typo in email address for patch 2
* Sat Oct 26 2013 peter.trommler@ohm-hochschule.de
- refresh suse-disable-debug-packages.patch
- refresh add-group.patch
- refresh files-defattr.patch
* Sat Oct 26 2013 peter.trommler@ohm-hochschule.de
- update to 1.2 from upstream
  * update for ghc 7.7 and later
  * fixes for bootstrapping new ghc
- drop buildService.patch
  * docdirs are unversioned now
* Fri Oct 11 2013 peter.trommler@ohm-hochschule.de
- add add-group.patch as patch 2
  * add Group tag to subpackages (required for SLE)
  * put libraries into System/Libraries (packaged guidelines)
  * fix bnc#845572
- add files-defattr.patch as patch 3
  * set file permissions according to specfile guidelines
- thanks to Scott Bahling for preparing those patches
- enable colorized documentation
* Thu Sep 26 2013 peter.trommler@ohm-hochschule.de
- clean up spec file
  * fix comment for patch 1 (wrong file name)
  * remove unused patch2 in setup section
* Thu Sep 26 2013 peter.trommler@ohm-hochschule.de
- enable colorized documentation for all Haskell packages
* Thu Aug  1 2013 dvaleev@suse.com
- fix %%{macros_dir}/macros.ghc for non x86 arches
* Wed May  1 2013 peter.trommler@ohm-hochschule.de
- put version back into html doc directory (needed by haddock)
* Wed May  1 2013 peter.trommler@ohm-hochschule.de
- fix library directory for ghc packages
* Wed May  1 2013 peter.trommler@ohm-hochschule.de
- drop library version in html documentation directory
* Mon Apr 29 2013 peter.trommler@ohm-hochschule.de
- add patch to fix ghc_gen_filelists macro
* Mon Apr 29 2013 peter.trommler@ohm-hochschule.de
- update to 0.99 from upstream
- support for ghc 7.6
- more transparent file lists
- macros dealing with subpackages moved to extra subbpackage
* Sat Mar  9 2013 peter.trommler@ohm-hochschule.de
- update to 0.98.1 from upstream
- new ghc_fix_dynamic_rpath macro to make executables work that
  are linked to their own library
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- openSUSE specific macros to disable debug packages
- refresh and remove .orig files from sle-sp1-rpmdeps.patch
* Mon Jun 25 2012 peter.trommler@ohm-hochschule.de
- update to 0.95.5.1 from upstream
- cabal-tweak-dep-ver: be careful only to match complete dep name and
  do not match beyond ","
- some cabal-tweak-dep-ver improvements:
- show file name when no match
- backslash quote . and * in the match string
- create a backup file if none exists
- new cabal-tweak-dep-ver script to tweak depends version bounds in .cabal
- ghc-dep.sh: only use buildroot package.conf.d if it exists
- ghc-deps.sh: look in buildroot package.conf.d for program deps
- add a meta-package option to ghc_devel_package and use in ghc_devel_requires
- let ghc_bin_install take an arg to disable implicit stripping for subpackages
- allow ghc_description, ghc_devel_description, ghc_devel_post_postun
  to take args
- fix doc handling of subpackages for ghc_without_shared
- move --disable-library-for-ghci to ghc_lib_build
- revert back to fallback behaviour for common_summary and common_description
  since it is needed for ghc and haskell-platform subpackaging
- without ghc_exclude_docdir include doc dir also for subpackages
- no longer build redundant ghci .o library files
- support meta packages like haskell-platform without base lib files
- make it possible not to have to use common_summary and common_description
- rename ghc_binlib_package to ghc_lib_subpackage
- add ghc_lib_build_without_haddock
- no longer drop into package dirs when subpackaging with ghc_lib_build and
  ghc_lib_install
- add shell variable cabal_configure_extra_options to cabal_configure for
  local configuration
* Sun Jun 24 2012 peter.trommler@ohm-hochschule.de
- cleaned up file list
- remove Obsoletes clauses from macros (buildService.patch)
- rebased sle-sp1-rpmdeps.patch
* Sat May  5 2012 peter.trommler@ohm-hochschule.de
- bumped version number to match upstream
- dropped fix for magic, not needed anymore
- added copyright notice
* Thu Apr 26 2012 peter.trommler@ohm-hochschule.de
- upgrade to 0.90 from upstream
- use new rpm metadata hash format for ghc-7.4
- drop prof meta hash data
- no longer include doc files automatically by default
- no longer provide doc subpackage
- do not provide prof when without_prof set
- remove SUSE_ASNEEDED in buildService.patch
- rebase sle patch
* Mon Mar 19 2012 peter.trommler@ohm-hochschule.de
- fix ghc-deps.sh (ignore builtin_ffi)
* Mon Mar 19 2012 peter.trommler@ohm-hochschule.de
- upgrade to 0.15.5 from upstream
- undo patch for dependency generation (redundant provides)
* Thu Feb 23 2012 peter.trommler@ohm-hochschule.de
- fix patch for sle11
* Tue Feb 21 2012 peter.trommler@ohm-hochschule.de
- define _rpmconfigdir on SLE-11-SP1
* Sun Feb 19 2012 peter.trommler@ohm-hochschule.de
- update to 0.15.4 from upstream
- patches rebased
- fix rpmdeps on SLE-11-SP1
* Mon Feb  6 2012 peter.trommler@ohm-hochschule.de
- do not pass .conf file to rpmdeps (fails on SLE-11-SP1)
* Thu Feb  2 2012 peter.trommler@ohm-hochschule.de
- remove version on docs dir
* Thu Feb  2 2012 peter.trommler@ohm-hochschule.de
- put documentation into /usr/share/doc/ghc-<version>
* Thu Feb  2 2012 peter.trommler@ohm-hochschule.de
- add build root tag (for SLE11)
* Sun Jan 22 2012 peter.trommler@ohm-hochschule.de
- Fix license tag
* Sun Jan 22 2012 peter.trommler@ohm-hochschule.de
- remove version numbers again
- move documentation to ghc-docs
* Sat Jan 21 2012 peter.trommler@ohm-hochschule.de
- update to version 0.15.2 from upstream
- put version numbers in packages back in
* Mon Dec 26 2011 peter.trommler@ohm-hochschule.de
- fix document directories
* Thu Dec 22 2011 peter.trommler@ohm-hochschule.de
- ghc-deps.sh: add dependencies for requires
* Sat Dec 10 2011 peter.trommler@ohm-hochschule.de
- ghc-deps.sh again
* Fri Dec  9 2011 peter.trommler@ohm-hochschule.de
- fixed ghc-deps.sh
* Fri Dec  9 2011 peter.trommler@ohm-hochschule.de
- generate dependencies that keep OBS happy
* Fri Dec  9 2011 peter.trommler@ohm-hochschule.de
- fixed sed unterminated s command
* Thu Dec  8 2011 peter.trommler@ohm-hochschule.de
- do not require builtin_ffi for executables
* Tue Dec  6 2011 peter.trommler@ohm-hochschule.de
- required packages format changed for executables
* Sat Dec  3 2011 peter.trommler@ohm-hochschule.de
- Upgraded to 0.14.3-1 from upstream
- added ghc dependency generator back in and started OBS fix for it
* Fri Nov 25 2011 peter.trommler@ohm-hochschule.de
- Fixed patch
* Thu Nov 24 2011 peter.trommler@ohm-hochschule.de
- Add SUSE_ASNEEDED=0
* Wed Nov 23 2011 peter.trommler@ohm-hochschule.de
- Upgraded to version 0.14.2 from upstream
- Disabled ghc dependency generator. It breaks all builds on OBS
* Mon Oct 31 2011 peter.trommler@ohm-hochschule.de
- Fix: Wrong files uploaded.
* Mon Oct 31 2011 peter.trommler@ohm-hochschule.de
- Upgraded to 0.13.13 from upstream.
* Mon Oct 17 2011 peter.trommler@ohm-hochschule.de
- Patch for openSUSE build service and package group names.
* Thu Oct 13 2011 peter.trommler@ohm-hochschule.de
- Undo patch.
* Wed Oct 12 2011 peter.trommler@ohm-hochschule.de
- use runghc in cabal macro to fing ghc libraries.
* Fri Oct  7 2011 peter.trommler@ohm-hochschule.de
- Removed redhat-rpm-config requres tag.
* Fri Oct  7 2011 peter.trommler@ohm-hochschule.de
- Fixed Group tag.
* Fri Oct  7 2011 peter.trommler@ohm-hochschule.de
- Initial packaging
